==> ejc-zjkjcost-impl-3.0.0-20220621.123023-4-sources.jar: com/ejianc/business/zjkjcost/finish/bean/OutDetailEntity.java <==
package com.ejianc.business.zjkjcost.finish.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 竣工考核-竣工目标考核奖金发放-子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_finish_out_detail")
public class OutDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="out_id")
    private Long outId; // 主表id
    @TableField(value="user_name")
    private String userName; // 姓名
    @TableField(value="job")
    private String job; // 岗位
    @TableField(value="sign")
    private String sign; // 分配人签字
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="detail_actual_mny")
    private BigDecimal detailActualMny; // 实发金额
    
    
    

    public Long getOutId() {
        return outId;
    }

    public void setOutId(Long outId) {
        this.outId = outId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getDetailActualMny() {
        return detailActualMny;
    }

    public void setDetailActualMny(BigDecimal detailActualMny) {
        this.detailActualMny = detailActualMny;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20220704.094919-26-sources.jar: com/ejianc/business/zjkjcost/finish/bean/OutDetailEntity.java <==
package com.ejianc.business.zjkjcost.finish.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 竣工考核-竣工目标考核奖金发放-子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_finish_out_detail")
public class OutDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="out_id")
    private Long outId; // 主表id
    @TableField(value="user_name")
    private String userName; // 姓名
    @TableField(value="job")
    private String job; // 岗位
    @TableField(value="sign")
    private String sign; // 分配人签字
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="detail_actual_mny")
    private BigDecimal detailActualMny; // 实发金额
    @TableField(value="detail_out_mny")
    private BigDecimal detailOutMny; // 分配金额

    public BigDecimal getDetailOutMny() {
        return detailOutMny;
    }

    public void setDetailOutMny(BigDecimal detailOutMny) {
        this.detailOutMny = detailOutMny;
    }

    public Long getOutId() {
        return outId;
    }

    public void setOutId(Long outId) {
        this.outId = outId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getDetailActualMny() {
        return detailActualMny;
    }

    public void setDetailActualMny(BigDecimal detailActualMny) {
        this.detailActualMny = detailActualMny;
    }
    
}
